from datetime import datetime

import pytest as pytest
import os
import vdocipher as vdocipher_lib
from vdocipher import Video


class BaseTest:

    vdocipher = vdocipher_lib
    vdocipher.authenticate(os.getenv('VDOCIPHER_API_SECRET', default=''))

    @pytest.yield_fixture
    def video(self) -> Video:

        with open('resources/test_file.mp4', 'rb') as file:
            video_name = f'test - {datetime.now()}'

            video_obj = self.vdocipher.Video(title=video_name).upload(file)

            assert isinstance(video_obj, Video)
            assert video_obj.id

            yield video_obj

            video_obj.delete()




from vdocipher import Video
from vdocipher.resources.video import Subtitle
from vdocipher.tests.conftest import BaseTest


class TestVideoSubtitle(BaseTest):

    def test_video_upload(self, video: Video):

        with open('resources/test_caption.vtt', 'rb') as subtitle_file:
            subtitle: Subtitle = video.upload_subtitle(subtitle_file, language='en')

            assert subtitle.id
            assert subtitle.size
            assert subtitle.time
            assert subtitle.lang




from dataclasses import dataclass, field
from typing import List

from dataclasses_json import dataclass_json, config


@dataclass_json
@dataclass
class IPGeoRule:
    actions: bool = None
    ip_set: List = field(metadata=config(field_name="ipSet"), default=None)
    country_set: List = field(metadata=config(field_name="countrySet"), default=None)






import json
from dataclasses import dataclass, field
from typing import List

from dataclasses_json import dataclass_json, config

from vdocipher.resources.annotate import Annotate
from vdocipher.resources.ip_geo_rule import IPGeoRule
from vdocipher.resources.license_rules import LicenseRules
from vdocipher.resources.request import post
from vdocipher.resources.routes.base import VIDEOS


@dataclass_json
@dataclass
class OTP:
    otp: str = None
    playback_info: str = field(metadata=config(field_name="playbackInfo"), default=None)
    annotations: List[Annotate] = None
    license_rules: LicenseRules = None
    ip_geo_rules: List[IPGeoRule] = None
    white_list_href: str = None

    def create(self, video_id: str, ttl: int = 300) -> 'OTP':
        data = {'ttl': ttl}

        if self.annotations:
            data['annotate'] = json.dumps([annotate.to_dict() for annotate in self.annotations])

        if self.license_rules:
            data['licenseRules'] = json.dumps(self.license_rules.to_dict())

        if self.white_list_href:
            data['whitelisthref'] = json.dumps(self.white_list_href)

        if self.ip_geo_rules:
            data['ipGeoRules'] = json.dumps([ip_rule.to_dict() for ip_rule in self.ip_geo_rules])

        response = post(url=f'{VIDEOS}/{video_id}/otp', data=json.dumps(data))

        return self.from_dict(response.json())
